@@ -1,12 +1,5 @@
 package BioX::SeqUtils::Promoter;
 #use base qw(BASE);
-####################################################################
-#	               Charles Stephen Embry			   #
-#	            MidSouth Bioinformatics Center		   #
-#	        University of Arkansas Little Rock	           #
-####################################################################
-
-
 use Class::Std;
 use Class::Std::Utils;
 
@@ -14,7 +7,7 @@ use warnings;
 use strict;
 use Carp;
 
-use version; our $VERSION = qv('0.1.1');
+use version; our $VERSION = qv('0.0.1');
 
 {
         my %attribute_of  :ATTR( :get<attribute>   :set<attribute>   :default<''>    :init_arg<attribute> );
@@ -40,12 +33,12 @@ __END__
 
 =head1 NAME
 
-BioX::SeqUtils::Promoter -Identification of core promoter elements and CpG islands in DNA sequeces via Consensus Sequences/Motifs 
+BioX::SeqUtils::Promoter - [One line description of module's purpose here]
 
 
 =head1 VERSION
 
-This document describes BioX::SeqUtils::Promoter version 0.1.1
+This document describes BioX::SeqUtils::Promoter version 0.0.1
 
 
 =head1 SYNOPSIS
