@@ -1,100 +1,27 @@
 package BioX::SeqUtils::Promoter::Alignment;
-####################################################################
-#	               Charles Stephen Embry			   #
-#	            MidSouth Bioinformatics Center		   #
-#	        University of Arkansas Little Rock	           #
-####################################################################
-use base qw(BioX::SeqUtils::Promoter::Base);
+#use base qw(BASE);
 use Class::Std;
 use Class::Std::Utils;
-use BioX::SeqUtils::Promoter::Sequences;
-use BioX::SeqUtils::Promoter::Annotations;
-use BioX::SeqUtils::Promoter::Annotations::Consensus;
-use BioX::SeqUtils::Promoter::SaveTypes;
+
 use warnings;
 use strict;
 use Carp;
-use Bio::Perl;
-use Bio::Seq;
-use Bio::SeqIO;
-use Bio::Tools::Run::Alignment::TCoffee;
 
-use version; our $VERSION = qv('0.1.1');
+use version; our $VERSION = qv('0.0.1');
 
 {
-        my %sequences_of  :ATTR( :get<sequences>   :set<sequences>   :default<''>    :init_arg<sequences> );
+        my %attribute_of  :ATTR( :get<attribute>   :set<attribute>   :default<''>    :init_arg<attribute> );
                 
         sub BUILD {
                 my ($self, $ident, $arg_ref) = @_;
         
- 
+
                 return;
         }
 
         sub START {
                 my ($self, $ident, $arg_ref) = @_;
-		my $sequences = BioX::SeqUtils::Promoter::Sequences->new();
-		$self->set_sequences($sequences);
-                return;
-        }
-
-        sub annotate {
-                my ($self,  $arg_ref) = @_;
-		my $filename = defined $arg_ref->{filename} ?  $arg_ref->{filename} : '';
-		my $annotations = BioX::SeqUtils::Promoter::Annotations->new({type => 'Consensus', motifs => $self->get_default_motifs() });
-		$annotations->print_motifs();
-  
-                return;
-        }
-
-        sub m_align {
-                my ($self,  $arg_ref) = @_;
-		#a file of fasta sequences will be a parameter
-		my $afilename = defined $arg_ref->{afilename} ?  $arg_ref->{afilename} : '';
-		#matrix used multiple alignment, can be Pam, Blosum or none
-		my $matrix = defined $arg_ref->{matrix} ?  $arg_ref->{matrix} : '';
-		#the pentaly for opening a gap in the alignment
-		my $gap_open = defined $arg_ref->{gap_open} ?  $arg_ref->{gap_open} : '';
-		#the pentaly for exiting a gap
-		my $gap_ext = defined $arg_ref->{gap_ext} ?  $arg_ref->{gap_ext} : '';
-		#name and location of output file
- 		my $outfile = '/home/stephen/BioCapstone/BioX-SeqUtils-Promoter/data/tnrab1000'; 
-		# Build a tcoffee alignment factory
-		#my @params = ('ktuple' => 2, 'matrix' => 'BLOSUM', 'OUTFILE' => tnrab1000.aln );
-		my @params = ('ktuple' => 2, 'matrix' => $matrix, 'GAPOPEN' => $gap_open, 'GAPEXT' => $gap_ext, 'OUTFILE' => $outfile);
-		#my @params = ('ktuple' => 2, 'matrix' => 'Pam', 'GAPOPEN' => 10, 'GAPEXT' => 2, 'OUTFILE' => p_GO10GE2_hexr );
-		#my @params = ('ktuple' => 2, 'matrix' => 'BLOSUM', 'OUTFILE' => $outfile);
-		# feed a list of parameters to Tcoffee
-		my $factory = Bio::Tools::Run::Alignment::TCoffee->new(@params);
-		# Pass the factory a list of sequences to be aligned.
-		# $aln is a SimpleAlign object.
-		my $aln = $factory->align($afilename);
-                
-		return;
-       }
-
-        sub load_alignmentfile {
-                my ($self,  $arg_ref) = @_;
-		#load a output file from a multiple sequence alignment
-		my $filename = defined $arg_ref->{filename} ?  $arg_ref->{filename} : '';
-		my $text;
-		#my $line;
-		my $sequences = $self->get_sequences();
-
-		open(IN,"<$filename");
-		
-		# takes each gene name and uses it as a key for a hash and the data for teh values
-		<IN>;
-		while($text = <IN>){
-		   	if($text) { 
-		   		#if($text =~/^$|^\s/){print "blank line\n"; next;}
-		   		if($text =~/^$|^\s/){next;}
-				my ($key, $value) = split /\s+/, $text;
-				$sequences->add_segment({label => $key, sequence => $value});
-			}	 
-		}
-		my $seqs = $sequences->get_sequences();
-		foreach my $key (keys %$seqs ){ print $seqs->{$key}->get_sequence(),"\n"; }
+        
 
                 return;
         }
@@ -106,12 +33,12 @@ __END__
 
 =head1 NAME
 
-BioX::SeqUtils::Promoter::Alignment - gets sequences and performs mulitple alignement 
+BioX::SeqUtils::Promoter::Alignment - [One line description of module's purpose here]
 
 
 =head1 VERSION
 
-This document describes BioX::SeqUtils::Promoter::Alignment version 0.1.1
+This document describes BioX::SeqUtils::Promoter::Alignment version 0.0.1
 
 
 =head1 SYNOPSIS
