@@ -1,47 +1,44 @@
 package BioX::SeqUtils::Promoter::Annotations;
-####################################################################
-#	               Charles Stephen Embry			   #
-#	            MidSouth Bioinformatics Center		   #
-#	        University of Arkansas Little Rock	           #
-####################################################################
-use base qw(BioX::SeqUtils::Promoter::Base);
+#use base qw(BASE);
 use Class::Std;
-use BioX::SeqUtils::Promoter::Sequence;
-use BioX::SeqUtils::Promoter::Sequences;
 use Class::Std::Utils;
-use Module::Runtime qw(use_module);
-
 
 use warnings;
 use strict;
 use Carp;
 
-use version; our $VERSION = qv('0.1.1');
+use version; our $VERSION = qv('0.0.1');
 
 {
-	no warnings 'redefine';
-	sub new {      
-		my ($self, $arg_ref) = @_;
-		my $type = defined $arg_ref->{type} ?  $arg_ref->{type} : '';
-		return use_module('BioX::SeqUtils::Promoter::Annotations::' . $type, 0.1.1)->new( $arg_ref );
-	}
+        my %attribute_of  :ATTR( :get<attribute>   :set<attribute>   :default<''>    :init_arg<attribute> );
+                
+        sub BUILD {
+                my ($self, $ident, $arg_ref) = @_;
+        
 
+                return;
+        }
 
+        sub START {
+                my ($self, $ident, $arg_ref) = @_;
+        
+
+                return;
+        }
 
 }
 
-
 1; # Magic true value required at end of module
 __END__
 
 =head1 NAME
 
-BioX::SeqUtils::Promoter::Annotations - identification of promoter elements in sequence ,sequences, or alignments
+BioX::SeqUtils::Promoter::Annotations - [One line description of module's purpose here]
 
 
 =head1 VERSION
 
-This document describes BioX::SeqUtils::Promoter::Annotations version 0.1.1
+This document describes BioX::SeqUtils::Promoter::Annotations version 0.0.1
 
 
 =head1 SYNOPSIS
