@@ -1,10 +1,5 @@
 package BioX::SeqUtils::Promoter::Annotations::Base;
-####################################################################
-#	               Charles Stephen Embry			   #
-#	            MidSouth Bioinformatics Center		   #
-#	        University of Arkansas Little Rock	           #
-####################################################################
-use base qw(BioX::SeqUtils::Promoter::Base);
+#use base qw(BASE);
 use Class::Std;
 use Class::Std::Utils;
 
@@ -12,7 +7,7 @@ use warnings;
 use strict;
 use Carp;
 
-use version; our $VERSION = qv('0.1.1');
+use version; our $VERSION = qv('0.0.1');
 
 {
         my %attribute_of  :ATTR( :get<attribute>   :set<attribute>   :default<''>    :init_arg<attribute> );
@@ -43,7 +38,7 @@ BioX::SeqUtils::Promoter::Annotations::Base - [One line description of module's
 
 =head1 VERSION
 
-This document describes BioX::SeqUtils::Promoter::Annotations::Base version 0.1.1
+This document describes BioX::SeqUtils::Promoter::Annotations::Base version 0.0.1
 
 
 =head1 SYNOPSIS
