@@ -1,9 +1,5 @@
 package BioX::SeqUtils::Promoter::Base;
-####################################################################
-#	               Charles Stephen Embry			   #
-#	            MidSouth Bioinformatics Center		   #
-#	        University of Arkansas Little Rock	           #
-####################################################################
+#use base qw(BASE);
 use Class::Std;
 use Class::Std::Utils;
 
@@ -11,9 +7,7 @@ use warnings;
 use strict;
 use Carp;
 
-use version; our $VERSION = qv('0.1.1');
-
-our $motifs = ['ATCGATA', 'CCGTTA', 'TATATGG' ];
+use version; our $VERSION = qv('0.0.1');
 
 {
         my %attribute_of  :ATTR( :get<attribute>   :set<attribute>   :default<''>    :init_arg<attribute> );
@@ -25,22 +19,13 @@ our $motifs = ['ATCGATA', 'CCGTTA', 'TATATGG' ];
                 return;
         }
 
-	sub get_default_motifs { return $motifs; }
-	
-	sub START {
+        sub START {
                 my ($self, $ident, $arg_ref) = @_;
         
 
                 return;
         }
 
-	sub length {
-                my ($self, $arg_ref) = @_;
-		my $string  = defined $arg_ref->{string} ?  $arg_ref->{string} : '';
-		my @letters = split('', $string);
-		#tells howlong a sequence is, important for other objects in Promoter module
-                return scalar(@letters);
-        }
 }
 
 1; # Magic true value required at end of module
@@ -48,12 +33,12 @@ __END__
 
 =head1 NAME
 
-BioX::SeqUtils::Promoter::Base - 
+BioX::SeqUtils::Promoter::Base - [One line description of module's purpose here]
 
 
 =head1 VERSION
 
-This document describes BioX::SeqUtils::Promoter::Base version 0.1.1
+This document describes BioX::SeqUtils::Promoter::Base version 0.0.1
 
 
 =head1 SYNOPSIS
