@@ -1,9 +1,4 @@
 package BioX::SeqUtils::Promoter::SaveTypes::Text;
-####################################################################
-#	               Charles Stephen Embry			   #
-#	            MidSouth Bioinformatics Center		   #
-#	        University of Arkansas Little Rock	           #
-####################################################################
 #use base qw(BASE);
 use Class::Std;
 use Class::Std::Utils;
@@ -12,7 +7,7 @@ use warnings;
 use strict;
 use Carp;
 
-use version; our $VERSION = qv('0.1.1');
+use version; our $VERSION = qv('0.0.1');
 
 {
         my %attribute_of  :ATTR( :get<attribute>   :set<attribute>   :default<''>    :init_arg<attribute> );
@@ -38,12 +33,12 @@ __END__
 
 =head1 NAME
 
-BioX::SeqUtils::Promoter::SaveTypes::Text - MSA output in text file format  
+BioX::SeqUtils::Promoter::SaveTypes::Text - [One line description of module's purpose here]
 
 
 =head1 VERSION
 
-This document describes BioX::SeqUtils::Promoter::SaveTypes::Text version 0.1.1
+This document describes BioX::SeqUtils::Promoter::SaveTypes::Text version 0.0.1
 
 
 =head1 SYNOPSIS
